@@ -238,8 +238,6 @@ FileDialog::FileDialog(QWidget* parent, FilePath path) :
         showHiddenAction->setChecked(proxyModel_->showHidden());
         thumbnailsAction->setChecked(proxyModel_->showThumbnails());
         tooltipsAction->setChecked(!noItemTooltip_);
-        perPixelAction->setVisible(viewMode_ == FolderView::DetailedListMode
-                                   || viewMode_ == FolderView::CompactMode);
         perPixelAction->setChecked(scrollPerPixel_);
     });
 
@@ -284,21 +282,35 @@ bool FileDialog::eventFilter(QObject* watched, QEvent* event) {
     if (watched == ui->folderView->childView()->viewport() && event->type() == QEvent::ToolTip) {
         return true;
     }
-    // Here we make Tab key switch the focus from the main view to the name entry
-    // and BackTab do the reverse because QWidget::setTabOrder() cannot do that.
     if(event->type() == QEvent::KeyPress) {
         if(QKeyEvent *ke = static_cast<QKeyEvent*>(event)) {
             if(watched == ui->folderView->childView() && ui->folderView->childView()->hasFocus()
-               && ke->key() == Qt::Key_Tab && ke->modifiers() == Qt::NoModifier) {
-                ui->fileName->setFocus();
-                // as in Qt -> QLineEdit::focusInEvent()
-                if(!ui->fileName->hasSelectedText()) {
-                    ui->fileName->selectAll();
+               && ke->modifiers() == Qt::NoModifier) {
+                if(ke->key() == Qt::Key_Tab) {
+                    // Here we make Tab key switch the focus from the main view to the name entry
+                    // and BackTab do the reverse because QWidget::setTabOrder() cannot do that.
+                    ui->fileName->setFocus();
+                    // as in Qt -> QLineEdit::focusInEvent()
+                    if(!ui->fileName->hasSelectedText()) {
+                        ui->fileName->selectAll();
+                    }
+                    return true;
+                }
+                else if(ke->key() == Qt::Key_Return || ke->key() == Qt::Key_Enter) {
+                    // Do not accept the dialog by pressing Enter/Return on the current item.
+                    // This prevents double acceptance and its side effects.
+                    QItemSelectionModel* selModel = ui->folderView->selectionModel();
+                    QModelIndex cur = selModel->currentIndex();
+                    if(cur.isValid() && selModel->isSelected(cur)) {
+                        if(auto file = proxyModel_->fileInfoFromIndex(cur)) {
+                            onFileClicked(FolderView::ActivatedClick, file); // activate the item
+                            return true;
+                        }
+                    }
                 }
-                return true;
             }
-            if(watched == ui->fileName && ui->fileName->hasFocus()
-               && ke->key() == Qt::Key_Backtab) {
+            else if(watched == ui->fileName && ui->fileName->hasFocus()
+                    && ke->key() == Qt::Key_Backtab) {
                 ui->folderView->childView()->setFocus();
                 return true;
             }
@@ -518,7 +530,7 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
     if(checkDefaultSuffix && !defaultSuffix_.isEmpty()) {
         return defaultSuffix_;
     }
-    // in the save mode, still try to make a suffix out of the currrent name filter
+    // in the save mode, still try to make a suffix out of the current name filter
     if(acceptMode_ != QFileDialog::AcceptOpen) {
         auto left = currentNameFilter_.lastIndexOf(QLatin1Char('('));
         if(left != -1) {
@@ -529,7 +541,10 @@ QString FileDialog::suffix(bool checkDefaultSuffix) const {
                 QString suffix = nameFilter.simplified().split(QLatin1Char(' '), Qt::SkipEmptyParts).at(0);
                 left = suffix.indexOf(QLatin1Char('.')); // it can be like ".tar.xz"
                 if(left != -1 && suffix.size() - left > 1) {
-                    return suffix.right(suffix.size() - left - 1);
+                    suffix = suffix.right(suffix.size() - left - 1);
+                    if(suffix.indexOf(QRegularExpression(QStringLiteral("\\W"))) == -1) {
+                        return suffix;
+                    }
                 }
             }
         }
@@ -1335,9 +1350,8 @@ void FileDialog::FileDialogFilter::update() {
     // parse the "*.ext1 *.ext2 *.ext3 ..." list into QRegularExpression objects
     const auto globs = nameFilter.simplified().split(QLatin1Char(' '));
     for(const auto& glob: globs) {
-        patterns_.emplace_back(QRegularExpression(QStringLiteral("\\A(?:")
-                                                    + QRegularExpression::wildcardToRegularExpression(glob)
-                                                    + QStringLiteral(")\\z"), QRegularExpression::CaseInsensitiveOption));
+        patterns_.emplace_back(QRegularExpression(QRegularExpression::wildcardToRegularExpression(glob),
+                                                  QRegularExpression::CaseInsensitiveOption));
     }
 }
 
