@@ -114,7 +114,6 @@ void FileDialogHelper::selectNameFilter(const QString& filter) {
     dlg_->selectNameFilter(filter);
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
 QString FileDialogHelper::selectedMimeTypeFilter() const {
     return dlg_->selectedMimeTypeFilter();
 }
@@ -122,7 +121,6 @@ QString FileDialogHelper::selectedMimeTypeFilter() const {
 void FileDialogHelper::selectMimeTypeFilter(const QString& filter) {
     dlg_->selectMimeTypeFilter(filter);
 }
-#endif
 
 QString FileDialogHelper::selectedNameFilter() const {
     return dlg_->selectedNameFilter();
@@ -170,7 +168,6 @@ void FileDialogHelper::applyOptions() {
     }
 
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 9, 0)
     auto filter = opt->initiallySelectedMimeTypeFilter();
     if(!filter.isEmpty()) {
         selectMimeTypeFilter(filter);
@@ -181,12 +178,6 @@ void FileDialogHelper::applyOptions() {
             selectNameFilter(opt->initiallySelectedNameFilter());
         }
     }
-#else
-    auto filter = opt->initiallySelectedNameFilter();
-    if(!filter.isEmpty()) {
-        selectNameFilter(filter);
-    }
-#endif
 
     const auto selectedFiles = opt->initiallySelectedFiles();
     for(const auto& selectedFile: selectedFiles) {
@@ -324,19 +315,23 @@ void FileDialogHelper::loadSettings() {
 
     dlg_->setShowThumbnails(settings.value(QStringLiteral("ShowThumbnails"), true).toBool());
     dlg_->setNoItemTooltip(settings.value(QStringLiteral("NoItemTooltip"), false).toBool());
+    dlg_->setScrollPerPixel(settings.value(QStringLiteral("ScrollPerPixel"), true).toBool());
 
     dlg_->setBigIconSize(settings.value(QStringLiteral("BigIconSize"), 48).toInt());
     dlg_->setSmallIconSize(settings.value(QStringLiteral("SmallIconSize"), 24).toInt());
     dlg_->setThumbnailIconSize(settings.value(QStringLiteral("ThumbnailIconSize"), 128).toInt());
+
+    const QList<QVariant> hiddenColumns = settings.value(QStringLiteral("HiddenColumns")).toList();
+    QList<int> l;
+    for(auto width : hiddenColumns) {
+        l << width.toInt();
+    }
+    dlg_->setHiddenColumns(l);
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Places"));
-#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
     QStringList hiddenPlacesList = settings.value(QStringLiteral("HiddenPlaces")).toStringList();
     QSet<QString> hiddenPlacesSet = QSet<QString>(hiddenPlacesList.begin(), hiddenPlacesList.end());
-#else
-    QSet<QString> hiddenPlacesSet = settings.value(QStringLiteral("HiddenPlaces")).toStringList().toSet();
-#endif
     dlg_->setHiddenPlaces(hiddenPlacesSet);
     settings.endGroup();
 }
@@ -393,6 +388,10 @@ void FileDialogHelper::saveSettings() {
     if(settings.value(QStringLiteral("NoItemTooltip")).toBool() != noItemTooltip) {
         settings.setValue(QStringLiteral("NoItemTooltip"), noItemTooltip);
     }
+    bool scrollPerPixel = dlg_->scrollPerPixel();
+    if(settings.value(QStringLiteral("ScrollPerPixel")).toBool() != scrollPerPixel) {
+        settings.setValue(QStringLiteral("ScrollPerPixel"), scrollPerPixel);
+    }
 
     int size = dlg_->bigIconSize();
     if(settings.value(QStringLiteral("BigIconSize")).toInt() != size) {
@@ -406,6 +405,16 @@ void FileDialogHelper::saveSettings() {
     if(settings.value(QStringLiteral("ThumbnailIconSize")).toInt() != size) {
         settings.setValue(QStringLiteral("ThumbnailIconSize"), size);
     }
+
+    const QList<int> columns = dlg_->getHiddenColumns();
+    QList<QVariant> hiddenColumns;
+    for(auto column : columns) {
+        hiddenColumns << QVariant(column);
+    }
+    std::sort(hiddenColumns.begin(), hiddenColumns.end());
+    if(settings.value(QStringLiteral("HiddenColumns")).toList() != hiddenColumns) {
+        settings.setValue(QStringLiteral("HiddenColumns"), hiddenColumns);
+    }
     settings.endGroup();
 
     settings.beginGroup(QStringLiteral("Places"));
@@ -414,18 +423,10 @@ void FileDialogHelper::saveSettings() {
         settings.remove(QStringLiteral("HiddenPlaces"));
     }
     else {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
         QStringList hiddenPlacesList = settings.value(QStringLiteral("HiddenPlaces")).toStringList();
         QSet<QString> hiddenPlacesSet = QSet<QString>(hiddenPlacesList.begin(), hiddenPlacesList.end());
-#else
-        QSet<QString> hiddenPlacesSet = settings.value(QStringLiteral("HiddenPlaces")).toStringList().toSet();
-#endif
         if (hiddenPlaces != hiddenPlacesSet) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,14,0))
             QStringList sl(hiddenPlaces.begin(), hiddenPlaces.end());
-#else
-            QStringList sl = hiddenPlaces.values();
-#endif
             settings.setValue(QStringLiteral("HiddenPlaces"), sl);
         }
     }
