@@ -81,6 +81,10 @@ PathBar::PathBar(QWidget* parent):
     buttonsLayout_->setSpacing(0);
     buttonsLayout_->setSizeConstraint(QLayout::SetFixedSize); // required when added to scroll area according to QScrollArea doc.
     scrollArea_->setWidget(buttonsWidget_); // make the buttons widget scrollable if the path is too long
+
+    // ensure the parent's background is shown behind the bar
+    scrollArea_->viewport()->setAutoFillBackground(false);
+    buttonsWidget_->setAutoFillBackground(false);
 }
 
 void PathBar::resizeEvent(QResizeEvent* event) {
@@ -186,7 +190,7 @@ void PathBar::onButtonToggled(bool checked) {
         currentPath_ = pathForButton(btn);
         Q_EMIT chdir(currentPath_);
 
-        // since scrolling to the toggled buton will happen correctly only when the
+        // since scrolling to the toggled button will happen correctly only when the
         // layout is updated and because the update is disabled on creating buttons
         // in setPath(), the update status can be used as a sign to know when to wait
         if(updatesEnabled()) {
